"""VELOCRIUM Authentication. Author: Juste Elysée MALANDILA"""

class BearerAuth:
    """Bearer token authentication."""
    def __init__(self, token: str):
        self.token = token

class OAuth2:
    """OAuth2 authentication."""
    def __init__(self, client_id: str, client_secret: str, token_url: str):
        self.client_id = client_id
        self.client_secret = client_secret
        self.token_url = token_url
