"""VELOCRIUM Cache - HTTP caching. Author: Juste Elysée MALANDILA"""

class Cache:
    """HTTP caching configuration."""
    def __init__(self, ttl: int = 300, backend: str = "memory"):
        self.ttl = ttl
        self.backend = backend
