"""VELOCRIUM Timeout configuration. Author: Juste Elysée MALANDILA"""

class Timeout:
    """Timeout configuration."""
    def __init__(self, connect: float = 5.0, read: float = 30.0, write: float = 30.0):
        self.connect = connect
        self.read = read
        self.write = write
    
    def to_httpx(self):
        return (self.connect, self.read, self.write, self.write)
