"""
VELOCRIUM Exceptions
Author: Juste Elysée MALANDILA
LinkedIn: https://linkedin.com/in/juste-elysee-malandila
"""


class VelocriumError(Exception):
    """Base exception for all Velocrium errors."""
    pass


class HTTPError(VelocriumError):
    """HTTP request failed with error status code."""
    pass


class TimeoutError(VelocriumError):
    """Request timed out."""
    pass


class RetryError(VelocriumError):
    """Request failed after all retry attempts."""
    pass


class RateLimitError(VelocriumError):
    """Rate limit exceeded."""
    pass


class CacheError(VelocriumError):
    """Cache operation failed."""
    pass


class AuthError(VelocriumError):
    """Authentication failed."""
    pass
